==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Trim/ts/Trim_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Trim</name>
    <message>
        <location filename="../Trim.js" line="+77"/>
        <source>Choose limiting entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz ograniczenie podmiotu</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Choose entity to trim</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz jednostkę do wykończenia</translation>
    </message>
    <message>
        <location line="+169"/>
        <source>The two entities don&apos;t intersect, or are currently not supported for trimming.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Oba podmioty nie przecinają się, ani nie są obecnie obsługiwane przez przycinanie.</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>First entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../TrimInit.js" line="+2"/>
        <source>&amp;Trim</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przytni&amp;j
Przytnij &amp;dwa</translatorcomment>
        <translation type="unfinished">Przytni&amp;j</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Trim/ts/Trim_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Trim</name>
    <message>
        <location filename="../Trim.js" line="+77"/>
        <source>Choose limiting entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać obiekt ograniczający</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Choose entity to trim</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać obiekt przycinany</translation>
    </message>
    <message>
        <location line="+169"/>
        <source>The two entities don&apos;t intersect, or are currently not supported for trimming.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Te dwa obiekty nie przecinają się lub aktualnie ich przycinanie nie jest obsługiwane.</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Nie można przyciąć pierwszego obiektu.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Nie można przyciąć obiektu.</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Nie można przyciąć drugiego obiektu.</translation>
    </message>
    <message>
        <location filename="../TrimInit.js" line="+2"/>
        <source>&amp;Trim</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przytni&amp;j
Przytnij &amp;dwa</translatorcomment>
        <translation>Przy&amp;tnij</translation>
    </message>
</context>
</TS>
